
Logical Operators
=================

There are three logical operators for conditions:

- ``&``: **AND** operator
- ``|``: **OR** operator
- ``~``: **NOT** operator

Examples:

.. literalinclude:: /code/conds/api/logic.py
    :language: py